/*
 * Copyright 2004-2010 the Seasar Foundation and the Others.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND,
 * either express or implied. See the License for the specific language
 * governing permissions and limitations under the License.
 */
package org.seasar.doma.jdbc.entity;

import org.seasar.doma.Update;

/**
 * 更新処理の後処理のコンテキストです。
 * 
 * @author taedium
 * @since 1.11.0
 */
public interface PostUpdateContext {

    /**
     * プロパティが変更されたかどうかを返します。
     * <p>
     * {@link Update#sqlFile()} に {@code false} が指定されたDaoメソッドによる実行でない場合、常に
     * {@code true}を返します。
     * 
     * @param propertyName
     *            プロパティ名
     * @return プロパティが変更されているかどうか
     * @exception EntityPropertyNotDefinedException
     *                プロパティがエンティティに定義されていない場合
     */
    public boolean isPropertyChanged(String propertyName);

    /**
     * エンティティのメタタイプを返します。
     * 
     * @return エンティティのメタタイプ
     */
    public EntityType<?> getEntityType();
}
